# A rule for debian packages to check that all files installed by the
# build are actually packaged.  To use it, place it in e.g. your debian/
# directory and add the following line to debian/rules:
#
#    include debian/checkmissing.mk
#
# and
#
#    binary: check-missing-files
#
# Set CHECK_MISSING_IGNORE_REGEXP to ignore files.  It should be a
# single regexp that matches exactly the files to be ignored.  It will
# be used in a grep -v call.
#
# This file is derived from utils.mk from cdbs.

check-missing-files:
	@if test -d debian/tmp; then \
	  (cd debian/tmp && find . -type f -o -type l | grep -v '/DEBIAN/' \
             | sed -e 's/\.gz$$//' | sort) > debian/cdbs-install-list; \
	  if [ -n "$(CHECK_MISSING_IGNORE_REGEXP)" ]; then \
	    cp debian/cdbs-install-list debian/cdbs-install-list.tmp; \
	    grep -v "$(CHECK_MISSING_IGNORE_REGEXP)" \
	        < debian/cdbs-install-list.tmp > debian/cdbs-install-list; \
	  fi; \
	  if [ -z "$(DEB_ALL_PACKAGES)" ]; then \
	    packages=$$(sed -n -e 's/Package: *//p' debian/control); \
	  else \
	    packages="$(DEB_ALL_PACKAGES)"; \
	  fi; \
	  echo "looking for missing files in $$packages"; \
	  (for package in $$packages; do \
	     (cd debian/$$package && find . -type f -o \( -type l -a ! -lname '/opt/maemo/*' \) | grep -v '/DEBIAN/'); \
	   done) | sed -e 's/\.gz$$//;s!\./opt/maemo!\.!' | sort -u > debian/cdbs-package-list; \
	  if test -e debian/not-installed ;\
	    then \
	    grep -v '^#' debian/not-installed >> debian/cdbs-package-list ; \
	    sort -u <debian/cdbs-package-list > debian/cdbs-package-list.tmp ;\
	    mv debian/cdbs-package-list.tmp debian/cdbs-package-list ; \
	  fi ;\
	  diff --new-group-format="" --unchanged-group-format="" \
               debian/cdbs-install-list debian/cdbs-package-list > debian/cdbs-unpackaged; \
	  if [ -s debian/cdbs-unpackaged ]; then \
	    echo "---- the following files were installed but not packaged:"; \
	    cat debian/cdbs-unpackaged; \
	    exit 1; \
	  else \
	    echo "all files were packaged"; \
	  fi \
	else \
	  echo "All files were installed into debian/$(DEB_SOURCE_PACKAGE)."; \
	fi


clean::
	rm -f debian/cdbs-unpackaged

# run
.PHONY: check-missing-files
